@@ -1,4 +1,4 @@
-# $Id: cwxn.py 1132 2014-11-24 15:13:52Z mwall $
+# $Id: cwxn.py 1177 2014-12-08 14:17:22Z mwall $
 # Copyright 2014 Matthew Wall
 """Emit loop data to wxnow.txt file with Cumulus format:
    http://wiki.sandaysoft.com/a/Wxnow.txt
@@ -26,7 +26,7 @@ import weeutil.weeutil
 import weeutil.Sun
 from weewx.engine import StdService
 
-VERSION = "0.2"
+VERSION = "0.3"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -76,9 +76,9 @@ class CumulusWXNow(StdService):
 
     def handle_new_loop(self, event):
         try:
-            with self.engine.db_binder.get_manager('wx_binding') as dbm:
-                data = self.calculate(event.packet, dbm)
-                self.write_data(data)
+            dbm = self.engine.db_binder.get_manager('wx_binding')
+            data = self.calculate(event.packet, dbm)
+            self.write_data(data)
         except Exception, e:
             weeutil.weeutil.log_traceback('cwxn: **** ')
 
